@@ -132,10 +132,15 @@ $breed_by_swcode = array
 	256  => 'ios12', // IOS 12.2 (router OS)
 	257  => 'ios12', // IOS 12.3 (router OS)
 	258  => 'ios12', // IOS 12.4 (router OS)
-	1901 => 'ios12', // IOS 15.0
+	1901 => 'ios12', // IOS 15.0 (switch)
+	2082 => 'ios12', // IOS 15.1 (switch)
+	2142 => 'ios12', // IOS 15.2 (switch)
+	2667 => 'ios12', // IOS 15.0 (router OS)
 	1963 => 'ios12', // IOS 15.1 (router OS)
-	2082 => 'ios12', // IOS 15.1
-	2142 => 'ios12', // IOS 15.2
+	2668 => 'ios12', // IOS 15.2 (router OS)
+	2669 => 'ios12', // IOS 15.3 (router OS)
+	2670 => 'ios12', // IOS 15.4 (router OS)
+	2671 => 'ios12', // IOS 15.5 (router OS)
 	963  => 'nxos4', // NX-OS 4.0
 	964  => 'nxos4', // NX-OS 4.1
 	1365 => 'nxos4', // NX-OS 4.2
